pub struct Session {
pub id: String,
pub agent: Agent,
pub name: String,
pub search_text: String,
pub workspace: PathBuf,
pub path: PathBuf,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
id: Stringagent: Agentname: Stringsearch_text: Stringworkspace: PathBufpath: PathBufcreated_at: DateTime<Utc>updated_at: DateTime<Utc>Implementations
Sourceimpl Session
impl Session
pub fn new( agent: Agent, session_id: String, workspace_dir: PathBuf, path: PathBuf, name: Option<String>, created_at: DateTime<Utc>, ) -> Self
Sourcepub fn build_resume_command(&self) -> Result<(&'static str, Vec<String>)>
pub fn build_resume_command(&self) -> Result<(&'static str, Vec<String>)>
Build the argv required to resume this session with its owning agent CLI.
Errors
Returns an error when the workspace path is not UTF-8 or the agent has no supported resume command.
fn build_codex_resume_args( &self, workspace: &str, is_zellij: bool, ) -> Vec<String>